@@ -9,7 +9,6 @@ from typing import Any, Dict, List, Optional, Set, Tuple
 import pandas as pd
 from mitosheet.code_chunks.code_chunk import CodeChunk
 from mitosheet.code_chunks.step_performers.column_steps.change_column_dtype_code_chunk import ChangeColumnDtypeCodeChunk
-from mitosheet.code_chunks.step_performers.column_steps.refresh_dependant_columns_code_chunk import RefreshDependantColumnsCodeChunk
 
 from mitosheet.errors import get_recent_traceback, make_invalid_column_type_change_error
 from mitosheet.sheet_functions.types import to_int_series
@@ -21,12 +20,10 @@ from mitosheet.sheet_functions.types.utils import (get_datetime_format,
                                                    is_bool_dtype,
                                                    is_datetime_dtype,
                                                    is_float_dtype,
-                                                   is_int_dtype,
+                                                   is_int_dtype, is_number_dtype,
                                                    is_string_dtype,
                                                    is_timedelta_dtype)
-from mitosheet.state import FORMAT_DEFAULT, State
-from mitosheet.step_performers.column_steps.set_column_formula import (
-    refresh_dependant_columns)
+from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.step_performers.utils import get_param
 from mitosheet.types import ColumnID
@@ -196,12 +193,10 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
             post_state.dfs[sheet_index][column_header] = new_column
             pandas_processing_time = perf_counter() - pandas_start_time
 
-            # If we're changing between number columns, we keep the formatting on the column. Otherwise, we remove it
-            if not ((is_int_dtype(old_dtype) or is_float_dtype(old_dtype)) and (is_int_dtype(new_dtype) or is_float_dtype(new_dtype))):
-                post_state.column_format_types[sheet_index][column_id] = {'type': FORMAT_DEFAULT}
+            # If we're changing away from a number column, then we remove the formatting on the column if it exists
+            if not is_number_dtype(new_dtype) and column_id in post_state.df_formats[sheet_index]['columns']:
+                del post_state.df_formats[sheet_index]['columns'][column_id]
                 
-            refresh_dependant_columns(post_state, post_state.dfs[sheet_index], sheet_index, column_id)
-
             return post_state, {
                 'pandas_processing_time': pandas_processing_time
             }
@@ -223,18 +218,7 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
         execution_data: Optional[Dict[str, Any]],
     ) -> List[CodeChunk]:
         return [
-            ChangeColumnDtypeCodeChunk(prev_state, post_state, params, execution_data),
-            # Note that we also refresh all the dependant columns, starting with the set cell value
-            RefreshDependantColumnsCodeChunk(
-                prev_state, 
-                post_state, 
-                # We construct the params for this CodeChunk as well
-                {
-                    'sheet_index': params['sheet_index'],
-                    'column_id': params['column_id'],
-                }, 
-                None
-            )
+            ChangeColumnDtypeCodeChunk(prev_state, post_state, params, execution_data)
         ]
 
     @classmethod
